﻿using System.Windows;
using System.Windows.Controls;

namespace Common.MVVM.ViewModels
{
    public class ViewModelWithWindowBase<T> : ViewModelBase<T> where T : class
    {

        #region UI views

        private FrameworkElement _quickNavPane;
        private FrameworkElement _currentView;

        /// <summary>
        /// Holds the Quick Navigation Pane to be displayed.
        /// </summary>
        /// <remarks></remarks>
        public FrameworkElement QuickNavPane
        {
            get { return _quickNavPane; }
            set { SetField(ref _quickNavPane, value, nameof(QuickNavPane)); }
        }


        private FrameworkElement _dialogWindowPane;

        /// <summary>
        /// Holds the Dialog to be displayed.
        /// </summary>
        /// <remarks></remarks>
        public FrameworkElement DialogWindowPane
        {
            get { return _dialogWindowPane; }
            set { SetField(ref _dialogWindowPane, value, nameof(DialogWindowPane)); }
        }




        /// <summary>
        /// Holds the UI view currently displayed.
        /// </summary>
        /// <remarks></remarks>
        public FrameworkElement CurrentView
        {
            get { return _currentView; }
            set { SetField(ref _currentView, value, nameof(CurrentView)); }
        }


        private FrameworkElement _currentRibbonView;
        /// <summary>
        /// Holds the UI ribbon view currently displayed.
        /// </summary>
        /// <remarks></remarks>
        public FrameworkElement CurrentRibbonView
        {
            get { return _currentRibbonView; }
            set { SetField(ref _currentRibbonView, value, nameof(CurrentRibbonView)); }
        }



        #endregion



        private System.Windows.Window _windowView;

        public Window WindowView
        {
            get { return _windowView; }
            private set { _windowView = value; }
        }

        public Window GetWindowView()
        {
            if (_windowView == null)
            {
                _windowView = CreateView<Window>(this);
            }

            return _windowView;
        }



 




 

        public void ShowWindow()
        {
            if (_windowView == null)
            {
                GetWindowView();
            }

            if (_windowView != null)
            {
                _windowView.Show();
            }
        }


        private UserControl _ribbonControl;

        public UserControl RibbonControl
        {
            get { return _ribbonControl; }
            set { SetField(ref _ribbonControl, value, nameof(RibbonControl)); }
        }










     





        private object _footer;

        public object Footer
        {
            get { return _footer; }
            set { SetField(ref _footer, value, nameof(Footer)); }
        }



      









    }
}
