using System;
using System.Linq;
using System.Collections.Generic;
using System.ComponentModel;
using Common.MVVM.ViewModels;
using MvvmBinding.Helpers;
using MvvmBinding.Models.Countries.Interfaces;
using MvvmBinding.Models.Customers;
using MvvmBinding.Models.Customers.Interfaces;
using MvvmBinding.ViewModels.Customers.Interfaces;

namespace MvvmBinding.ViewModels.Customers
{
  public class CustomerEditViewModel : ViewModelWithDialogWindowBase<CustomerEditModel>, ICustomerEditViewModel
  {

    /// <summary>
    /// A property of an observable collection of countries for the view.
    /// </summary>
    public ICollection<ICountry> CountryCollection => Model?.Countries?.ToObservableCollection();

    private ICountry _country;
    public ICountry SelectedCountry
    {
      get { return _country; }
      set
      {
        _country = value;
      }
    }
    /// <summary>
    /// Constructor.
    /// </summary>
    public CustomerEditViewModel()
    {
     
    }

    /// <summary>
    /// Initializes this view model.
    /// </summary>
    public override void Initialize()
    {
      base.Initialize();

      if (Model == null) throw new InvalidOperationException(nameof(Model));

      Model.ModelChanged += OnModelChanged;

      Model.GetCountries();

      
    }

    /// <summary>
    /// Model has changed so test which model property has changed and invoke the related view model property.
    /// </summary>
    /// <param name="sender"></param>
    /// <param name="propertyChangedEventArgs"></param>
    public void OnModelChanged(object sender, PropertyChangedEventArgs propertyChangedEventArgs)
    {
      if (propertyChangedEventArgs == null) throw new ArgumentNullException(nameof(propertyChangedEventArgs));

      if (string.Equals(propertyChangedEventArgs.PropertyName, "Countries", StringComparison.OrdinalIgnoreCase))
      {
        OnPropertyChanged(nameof(CountryCollection));
        var model = this.Model;

        if(model.CountryId == 0)
        {
          model.CountryId = 1;
        }

        var country = CountryCollection.Where(c => c.CountryId == model.CountryId).First();
        this.SelectedCountry = country;
      }
    }

    /// <summary>
    /// Refresh the viewmodel.
    /// </summary>
    public void RefreshViewModel(ICustomer customer)
    {
      if (customer == null) throw new ArgumentNullException(nameof(customer));

      Model.PopulateCustomer(customer);
    }



  }
}
