﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Text;
using System.Windows.Input;
using Common.MVVM.Binding;
using Common.MVVM.ViewModels;
using Common.Unity;
using MvvmBinding.Helpers;
using MvvmBinding.Models.Customers;
using MvvmBinding.Models.Customers.Interfaces;
using MvvmBinding.ViewModels.Customers.Interfaces;

namespace MvvmBinding.ViewModels.Customers
{
    public class CustomerListViewModel : ViewModelWithUserControlBase<CustomerListModel>, ICustomerListViewModel
    {
        private ICustomerEditViewModel _customerEditViewModel;
        private ICustomer _selectedCustomer;
        public ICommand ViewCustomerCommand => new RelayCommand(ViewCustomer);

        /// <summary>
        /// A property of an observable collection of customers for the view.
        /// </summary>
        public ICollection<ICustomer> CustomerCollection => Model?.Customers?.ToObservableCollection();

        /// <summary>
        /// Holds the customer that the user has selected.
        /// </summary>
        public ICustomer SelectedCustomer
        {
            get => _selectedCustomer;
            set => SetField(ref _selectedCustomer, value, nameof(SelectedCustomer));
        }

        /// <summary>
        /// Constructor.
        /// </summary>
        public CustomerListViewModel()
        {
        }

        /// <summary>
        /// Initializes this view model.
        /// </summary>
        public override void Initialize()
        {
            base.Initialize();
            
            if (Model == null) throw new InvalidOperationException(nameof(Model));

            Model.ModelChanged += OnModelChanged;
        }

        /// <summary>
        /// Model has changed so test which model property has changed and invoke the related view model property.
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="propertyChangedEventArgs"></param>
        public void OnModelChanged(object sender, PropertyChangedEventArgs propertyChangedEventArgs)
        {
            if (propertyChangedEventArgs == null) throw new ArgumentNullException(nameof(propertyChangedEventArgs));

            if (string.Equals(propertyChangedEventArgs.PropertyName, "Customers", StringComparison.OrdinalIgnoreCase))
            {
                OnPropertyChanged(nameof(CustomerCollection));
            }
        }

        public void RefreshViewModel()
        {
            Model.GetCustomers();
        }

        /// <summary>
        /// 
        /// </summary>
        /// <param name="obj"></param>
        private void ViewCustomer(object obj)
        {
            if (obj == null) throw new ArgumentNullException(nameof(obj));

            var customer = (ICustomer) obj;

            ShowCustomerEditDialog(customer);
        }

        private void ShowCustomerEditDialog(ICustomer customer)
        {
            if (customer == null) throw new ArgumentNullException(nameof(customer));

            _customerEditViewModel = UnityService.Resolve<ICustomerEditViewModel>();
            _customerEditViewModel.Initialize();
            _customerEditViewModel.RefreshViewModel(customer);

            _customerEditViewModel.ShowXamDialogWindow();
        }




    }
}
