﻿#region Namespaces
using System;
using System.Threading.Tasks;
using System.Windows;
using Common.MVVM.Messages;
using Common.MVVM.ViewModels;
using MvvmBinding.Models.JobTracker.Dashboard;
using MvvmBinding.ViewModels.Customers.Interfaces;
using MvvmBinding.ViewModels.Dashboard.Interfaces;
#endregion

namespace MvvmBinding.ViewModels.Dashboard
{
    public class DashboardViewModel : ViewModelWithUserControlBase<DashboardModel>,
                                      IDashboardViewModel
    {
        private readonly ICustomerListViewModel _customerListViewModel;
        private FrameworkElement _customerListPane;
        
        /// <summary>
        /// Holds the UI view for the list of customers that the user can select for more detailed viewing.
        /// </summary>
        /// <remarks></remarks>
        public FrameworkElement CustomerListPane
        {
            get { return _customerListPane; }
            set { SetField(ref _customerListPane, value, nameof(CustomerListPane)); }
        }

        /// <summary>
        /// Constructor.
        /// </summary>
        /// <param name="customerListViewModel"></param>
        public DashboardViewModel(ICustomerListViewModel customerListViewModel)
        {
            _customerListViewModel = customerListViewModel ?? throw new ArgumentNullException(nameof(customerListViewModel));
        }

        /// <summary>
        /// Initializes this view model.
        /// </summary>
        public override void Initialize()
        {
            base.Initialize();

            _customerListViewModel.Initialize();
            _customerListViewModel.RefreshViewModel();
            CustomerListPane = _customerListViewModel.GetUserControlView();
        }




    }
}
